@@ -27,6 +27,7 @@
 #include "symfonievolumedialog.h"
 #include "symfonieseekslider.h"
 #include "symfonielabelignoreevent.h"
+#include "symfonieqmenu.h"
 
 
 MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent) :
@@ -42,7 +43,8 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         currentOrientationMode(Qt::WA_Maemo5LandscapeOrientation),
         isInPortait(false),
         isResumePlayback(false),
-        isMainToolbarVisible(false)
+        isMainToolbarVisible(false),
+        fileListWidgetItemFileToDelete(QString())
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
@@ -209,7 +211,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-   // this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
+    // this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
 
 
 
@@ -250,7 +252,8 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
     this->ui->fileListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
+
+    // connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
 
 
 
@@ -291,20 +294,66 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     }
 
 
-     connect(orientationGroup, SIGNAL(triggered(QAction *)), this, SLOT(orientationChanged(QAction *)));
+    connect(orientationGroup, SIGNAL(triggered(QAction *)), this, SLOT(orientationChanged(QAction *)));
 
 
 }
 
 void MainWindow::deleteFileSlot(){
+    qDebug() << "Trying to delete file: " <<this->fileListWidgetItemFileToDelete;
+
+    QMessageBox msgBox;
+    // msgBox.setText(tr("File Deletion"));
+     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + this->fileListWidgetItemFileToDelete);
+     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
+     msgBox.setDefaultButton(QMessageBox::No);
+     int ret = msgBox.exec();
+
+     if(ret != QMessageBox::Yes){
+         qDebug() << "use cancelled.";
+         return;
+     }
+
+
+    QFileInfo info = QFileInfo(this->fileListWidgetItemFileToDelete);
+    if(!info.exists() || !info.isFile()){
+        qDebug() << "deleteFileSlot: not a filed, operation skipped.";
+        return;
+    }
+
+  //  this->getPlayer()->getMediaObject()->stop();
+
+    if(!QFile::remove(this->fileListWidgetItemFileToDelete)){
+        qDebug() << "deleteFileSlot: deletion failed: "<< this->fileListWidgetItemFileToDelete;
+        return;
+    }
+
+    this->getPlayer()->scanDir(this->getCurrentDiretory());
 
 
 }
 
 void MainWindow::fileListItemContextMenu(const QPoint &pos){
-    QMenu *menu = new QMenu;
-    menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+
+    QListWidgetItem *item = this->ui->fileListWidget->itemAt(pos);
+    int itemIndex;
+
+    if(item == NULL){
+        return;
+    }
+
+    itemIndex = item->data(Qt::UserRole).toInt();
+
+    SymfonieQMenu *menu = new SymfonieQMenu();
+
+
+    if(this->getPlayer()->getPlayList()->get(itemIndex)->getItemType() == SymfoniePlayListItemFile::File){
+        this->fileListWidgetItemFileToDelete = this->getPlayer()->getPlayList()->get(itemIndex)->getName();
+        menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+    }
     menu->exec(this->mapToGlobal(pos));
+   // delete menu;
+    this->fileListWidgetItemFileToDelete = QString();
 
 
 }
@@ -434,12 +483,12 @@ void MainWindow::setOrientationMode(int mode){
         setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
         this->setupToolBarButtonsLandscape();
     }
-/*
+    /*
     this->orientationLandscape->setChecked(mode == Qt::WA_Maemo5LandscapeOrientation);
     this->orientationPortrait->setChecked(mode == Qt::WA_Maemo5PortraitOrientation);
     this->orientationAuto->setChecked(mode == Qt::WA_Maemo5AutoOrientation);
   */
-      this->currentOrientationMode = mode;
+    this->currentOrientationMode = mode;
 
 }
 
@@ -538,7 +587,7 @@ void MainWindow::showVolumeDialogSlot(){
 
         this->volumeDialog->layout()->addWidget(this->volumeSlider);
 
-/*
+        /*
         connect(this->volumeDialog, SIGNAL(finished(int)),
                 this, SLOT(volumeDialogClosedSlot(int)));
                 */
@@ -782,6 +831,7 @@ void MainWindow::showToolBar2Slot(){
 
 
 void MainWindow::stopSlot(){
+
 }
 
 
@@ -848,6 +898,8 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
 
         newItem->setText(item->getDisplayName());
+        //qDebug() << QVariant(itemList->indexOf(item)) ;
+        newItem->setData(Qt::UserRole, QVariant(itemList->indexOf(item)));
         ui->fileListWidget->insertItem(counter, newItem);
 
 
